@@ -5,6 +5,7 @@ OC.L10N.register(
     "Error" : "خطأ",
     "New note" : "ملاحظة جديدة ",
     "Settings" : "الإعدادات",
+    "All notes" : "جميع الملاحظات\n",
     "Categories" : "الفئات",
     "Today" : "اليوم",
     "Yesterday" : "البارحة",
@@ -20,6 +21,7 @@ OC.L10N.register(
     "Preview" : "معاينة",
     "Edit" : "تعديل",
     "Category" : "الفئة",
+    "Uncategorized" : "غير مصنف",
     "Saving failed!" : "فشلت عملية الحفظ !",
     "_%n word_::_%n words_" : ["كلمة","كلمة","كلمتان","كلمات","كلمات","كلمات"],
     "Android app" : "تطبيق الأندرويد",
