@@ -3,9 +3,8 @@ OC.L10N.register(
     {
     "Notes" : "Notas",
     "The last viewed note cannot be accessed. " : "No se puede acceder a la última nota consultada. ",
-    "New note" : "Nota nueva",
-    "Encryption Error" : "Error de encripción",
     "Error" : "Error",
+    "New note" : "Nota nueva",
     "Distraction-free notes and writing" : "Notas y escritura libre de distracciones",
     "Settings" : "Configuraciones ",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
@@ -15,6 +14,7 @@ OC.L10N.register(
     "Yesterday" : "Ayer",
     "This week" : "Esta semana",
     "This month" : "Este mes",
+    "Rename" : "Renombrar",
     "Delete note" : "Borrar nota",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a favoritos",
