@@ -4,9 +4,8 @@ OC.L10N.register(
     "Notes" : "Muistiinpanot",
     "The last viewed note cannot be accessed. " : "Ei pääsyä viimeksi katsottuun muistiinpanoon.",
     "The notes folder is not accessible: %s" : "Ei pääsyä muistiinpanokansioon: %s",
-    "New note" : "Uusi muistiinpano",
-    "Encryption Error" : "Salausvirhe",
     "Error" : "Virhe",
+    "New note" : "Uusi muistiinpano",
     "Settings" : "Asetukset",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Havaittiin tallentamattomia muistiinpanoja. Sivulta poistuminen hylkää kaikki muutokset!",
     "Folder to store your notes" : "Kansio johon muistiinpanot tallennetaan",
@@ -25,6 +24,7 @@ OC.L10N.register(
     "Last week" : "Viime viikolla",
     "This month" : "Tässä kuussa",
     "Last month" : "Viime kuussa",
+    "Rename" : "Nimeä uudelleen",
     "Delete note" : "Poista muistiinpano",
     "Remove from favorites" : "Poista suosikeista",
     "Add to favorites" : "Lisää suosikkeihin",
