@@ -6,11 +6,12 @@ OC.L10N.register(
     "New note" : "Нова нотатка",
     "Settings" : "Налаштування",
     "Categories" : "Категорії",
+    "Loading …" : "Завантаження...",
     "Today" : "Сьогодні",
     "Yesterday" : "Вчора",
     "Rename" : "Перейменувати",
     "Delete note" : "Вилучити нотатку",
-    "Remove from favorites" : "Видалено з улюбленого",
+    "Remove from favorites" : "Вилучено з улюбленого",
     "Add to favorites" : "Додати до обраного",
     "Details" : "Деталі",
     "Edit" : "Редашувати",
